@@ -31,6 +31,7 @@ use TYPO3\CMS\Backend\View\ValueFormatter\FlexFormValueFormatter;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\DataHandling\History\RecordHistoryStore;
 use TYPO3\CMS\Core\DataHandling\TableColumnType;
+use TYPO3\CMS\Core\Domain\DateTimeFactory;
 use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Imaging\IconSize;
 use TYPO3\CMS\Core\Localization\LanguageService;
@@ -178,7 +179,7 @@ class ElementHistoryController
         $schema = $this->tcaSchemaFactory->get($table);
         $this->view->assignMultiple([
             'recordTable' => $table,
-            'recordTableReadable' => $this->getLanguageService()->sL($schema->getRawConfiguration()['title'] ?? ''),
+            'recordTableReadable' => $schema->getTitle($this->getLanguageService()->sL(...)),
             'recordUid' => $uid,
             'recordTitle' => $this->generateTitle($table, (string)$uid),
         ]);
@@ -315,7 +316,7 @@ class ElementHistoryController
             $singleLine['diffUrl'] = $this->buildUrl(['historyEntry' => $entry['uid']]);
             // Add time
             $singleLine['day'] = BackendUtility::date($entry['tstamp']);
-            $singleLine['time'] = BackendUtility::time($entry['tstamp']);
+            $singleLine['timestamp'] = DateTimeFactory::createFromTimestamp($entry['tstamp']);
 
             $singleLine['title'] = $this->generateTitle($entry['tablename'], (string)$entry['recuid']);
             $singleLine['recordTable'] = $entry['tablename'];
@@ -323,7 +324,7 @@ class ElementHistoryController
 
             $singleLine['elementUrl'] = $this->buildUrl(['element' => $entry['tablename'] . ':' . $entry['recuid']]);
             $singleLine['actiontype'] = $entry['actiontype'];
-            if ((int)$entry['actiontype'] === RecordHistoryStore::ACTION_MODIFY) {
+            if ((int)$entry['actiontype'] === RecordHistoryStore::ACTION_MODIFY || (int)$entry['actiontype'] === RecordHistoryStore::ACTION_PUBLISH) {
                 // show changes
                 if (!$this->showDiff) {
                     // Display field names instead of full diff
@@ -470,9 +471,11 @@ class ElementHistoryController
             return false;
         }
 
+        $schema = $this->tcaSchemaFactory->get($tableName);
+
         // Early return if $elementUid is zero
         if ($elementUid === 0) {
-            return !$this->tcaSchemaFactory->get($tableName)->getCapability(TcaSchemaCapability::RestrictionRootLevel)->shallIgnoreRootLevelRestriction();
+            return !$schema->getCapability(TcaSchemaCapability::RestrictionRootLevel)->shallIgnoreRootLevelRestriction();
         }
 
         $record = BackendUtility::getRecord($tableName, $elementUid, '*', '', false);
@@ -482,6 +485,7 @@ class ElementHistoryController
             $record = BackendUtility::getRecord('pages', $pageId, '*', '', false);
         }
 
-        return (bool)$record['editlock'];
+        return $schema->hasCapability(TcaSchemaCapability::EditLock)
+            && ($record[$schema->getCapability(TcaSchemaCapability::EditLock)->getFieldName()] ?? false);
     }
 }
